import { StructureType, TopicType } from "@/enum";
import { MindMapProjectInfo, TopicItem } from "@/types";
import Hierarchy from "@antv/hierarchy";

// 思维导图结构实现
export const hierarchyMethodMap: Record<
  string,
  (topic: TopicItem, pageSetting: MindMapProjectInfo["pageSetting"]) => any
> = {
  // 右侧图
  [StructureType.right]: <T>(
    topic: TopicItem,
    pageSetting: MindMapProjectInfo["pageSetting"]
  ): T => {
    return Hierarchy.mindmap(topic, {
      direction: "H",
      getHeight(d: TopicItem) {
        return d.height;
      },
      getWidth(d: TopicItem) {
        return d.width;
      },
      getHGap(d: TopicItem) {
        if(d.type === TopicType.main) return pageSetting.branchX || 20;
        if(d.type === TopicType.branch) return pageSetting.subTopicX || 20;
        if(d.type === TopicType.sub) return pageSetting.subTopicX || 20;
        return pageSetting.branchX || 40;
      },
      getVGap() {
        return pageSetting.branchY || 20;
      },
      getSide: () => {
        return "right";
      },
    });
  },

};
